@@ -71,7 +71,7 @@ class InstantCoverageMixin(object):
 
         for url in self.covered_urls:
             try:
-                response = self.client.get(url)
+                response = self.client.get(url, follow=True)
             except Exception:
                 errors[url] = sys.exc_info()
             else:
@@ -93,6 +93,11 @@ class InstantCoverageMixin(object):
             self.client = Client()
 
     def instant_responses(self):
+        """
+        Return a dictionary of responses, as returned by the Django test
+        client, keyed by URL.
+        """
+
         return self._get_from_instant_cache('responses')
 
     def instant_errors(self):
